@@ -336,6 +336,7 @@ void config_state::conf_register(adv_conf* config_context)
 	conf_string_register_default(config_context, "ui_skiphorz", "auto");
 	conf_string_register_default(config_context, "ui_skipvert", "auto");
 	conf_bool_register_default(config_context, "ui_autocalib", 0);
+	conf_string_register_default(config_context, "ui_autocalib_reset", "");
 	conf_bool_register_default(config_context, "ui_outline", 1);
 	conf_bool_register_default(config_context, "ui_topname", 0);
 	conf_bool_register_default(config_context, "ui_topbar", 1);
@@ -847,6 +848,7 @@ bool config_state::load(adv_conf* config_context, bool opt_verbose)
 	ui_top = conf_int_get_default(config_context, "ui_skiptop");
 	ui_bottom = conf_int_get_default(config_context, "ui_skipbottom");
 	ui_autocalib = conf_bool_get_default(config_context, "ui_autocalib");
+	ui_autocalib_reset = conf_string_get_default(config_context, "ui_autocalib_reset");
 	ui_outline = conf_bool_get_default(config_context, "ui_outline");
 	ui_top_name = conf_bool_get_default(config_context, "ui_topname");
 	ui_top_bar = conf_bool_get_default(config_context, "ui_topbar");
