@@ -2205,6 +2205,8 @@ static adv_error input_load_map(struct advance_input_context* context, adv_conf*
 			s = conf_string_get_default(cfg_context, tag_buffer);
 			d = strdup(s);
 
+			log_std(("emu:input: input_map[%s] '%s'\n", tag_buffer, d));
+
 			if (parse_analog(context->config.analog_map[i][j].seq, d) != 0) {
 				free(d);
 				target_err("Invalid argument '%s' for option '%s'.\n%s.\n", s, tag_buffer, error_get());
@@ -2225,19 +2227,9 @@ static adv_error input_load_map(struct advance_input_context* context, adv_conf*
 		/* get the game option */
 		if (conf_string_get(cfg_context, tag_buffer, &s) == 0) {
 			char* d = strdup(s);
-			unsigned seq[INPUT_MAP_MAX];
-			if (advance_input_parse_digital(seq, INPUT_MAP_MAX, d) != 0) {
-				free(d);
-				target_err("Invalid argument '%s' for option '%s'.\n%s.\n", s, tag_buffer, error_get());
-				target_err("Valid format is keyboard[BOARD,KEY]/joystick_button[JOYSTICK,BUTTON]/mouse_button[MOUSE,BUTTON].\n");
-				return -1;
-			}
-			free(d);
-		}
 
-		/* get the default option */
-		if (conf_string_section_get(cfg_context, "", tag_buffer, &s) == 0) {
-			char* d = strdup(s);
+			log_std(("emu:input: input_map[%s] '%s'\n", tag_buffer, d));
+
 			unsigned seq[INPUT_MAP_MAX];
 			if (advance_input_parse_digital(seq, INPUT_MAP_MAX, d) != 0) {
 				free(d);
