@@ -30,6 +30,311 @@
 
 /* the first match is used */
 
+{ "tkmmpzdm", 22 }, /* 4.0 */
+{ "3in1semi", 4 }, /* 4.0 */
+{ "woodpek", 2 }, /* 4.0 */
+{ "wg3dh", 21 }, /* 4.0 */
+{ "welltris", 17 }, /* 4.0 */
+{ "wwallyj", 13 }, /* 4.0 */
+{ "goonies", 17 }, /* 4.0 */
+{ "vsgradus", 17 }, /* 4.0 */
+{ "viostorm", 32 }, /* 4.0 */
+{ "vimana", 9 }, /* 4.0 */
+{ "viewpoin", 8 }, /* 4.0 */
+{ "victroad", 6 }, /* 4.0 */
+{ "vendetta", 3 }, /* 4.0 */
+{ "varth", 11 }, /* 4.0 */
+{ "vandyke", 11 }, /* 4.0 */
+{ "vsav", 22 }, /* 4.0 */
+{ "vsav2", 19 }, /* 4.0 */
+{ "vhunt2r1", 23 }, /* 4.0 */
+{ "valkyrie", 4 }, /* 4.0 */
+{ "vfive", 12 }, /* 4.0 */
+{ "usclssic", 7 }, /* 4.0 */
+{ "twinhawk", 6 }, /* 4.0 */
+{ "tron", 3 }, /* 4.0 */
+{ "triplep", 3 }, /* 4.0 */
+{ "toypop", 3 }, /* 4.0 */
+{ "todruaga", 3 }, /* 4.0 */
+{ "turtles", 3 }, /* 4.0 */
+{ "truxton", 5 }, /* 4.0 */
+{ "tnexspce", 9 }, /* 4.0 */
+{ "kof97", 6 }, /* 4.0 */
+{ "karatour", 2 }, /* 4.0 */
+{ "theend", 3 }, /* 4.0 */
+{ "astyanax", 10 }, /* 4.0 */
+{ "mrflea", 4 }, /* 4.0 */
+{ "tetris", 6 }, /* 4.0 */
+{ "term2", 9 }, /* 4.0 */
+{ "tbowl", 4 }, /* 4.0 */
+{ "tangtang", 4 }, /* 4.0 */
+{ "cupfinal", 9 }, /* 4.0 */
+{ "tokkae", 5 }, /* 4.0 */
+{ "suzuk8h2", 2 }, /* 4.0 */
+{ "suzuka8h", 2 }, /* 4.0 */
+{ "susume", 34 }, /* 4.0 */
+{ "sws", 13 }, /* 4.0 */
+{ "sws97", 9 }, /* 4.0 */
+{ "sws96", 3 }, /* 4.0 */
+{ "sws95", 10 }, /* 4.0 */
+{ "swcourt", 7 }, /* 4.0 */
+{ "sstingry", 2 }, /* 4.0 */
+{ "macross2", 5 }, /* 4.0 */
+{ "sqix", 11 }, /* 4.0 */
+{ "spang", 10 }, /* 4.0 */
+{ "superpac", 6 }, /* 4.0 */
+{ "suplup", 3 }, /* 4.0 */
+{ "usg32", 3 }, /* 4.0 */
+{ "superchs", 4 }, /* 4.0 */
+{ "sbishi", 13 }, /* 4.0 */
+{ "ssriders", 5 }, /* 4.0 */
+{ "subroc3d", 3 }, /* 4.0 */
+{ "strkfgtr", 11 }, /* 4.0 */
+{ "strider2", 14 }, /* 4.0 */
+{ "strider", 3 }, /* 4.0 */
+{ "mp_sor2", 5 }, /* 4.0 */
+{ "sfiii3", 6 }, /* 4.0 */
+{ "sfiii2", 6 }, /* 4.0 */
+{ "sf2ce", 14 }, /* 4.0 */
+{ "sf2", 14 }, /* 4.0 */
+{ "sfex2p", 16 }, /* 4.0 */
+{ "sfa", 15 }, /* 4.0 */
+{ "sf", 11 }, /* 4.0 */
+{ "stmblade", 6 }, /* 4.0 */
+{ "stonebal", 20 }, /* 4.0 */
+{ "stinger", 4 }, /* 4.0 */
+{ "sgunner2", 3 }, /* 4.0 */
+{ "stargate", 11 }, /* 4.0 */
+{ "starblad", 23 }, /* 4.0 */
+{ "starswep", 7 }, /* 4.0 */
+{ "starglad", 14 }, /* 4.0 */
+{ "squash", 7 }, /* 4.0 */
+{ "splatter", 4 }, /* 4.0 */
+{ "speedspn", 2 }, /* 4.0 */
+{ "spdcoin", 2 }, /* 4.0 */
+{ "mp_soni2", 5 }, /* 4.0 */
+{ "mp_sonic", 5 }, /* 4.0 */
+{ "sonson", 13 }, /* 4.0 */
+{ "skyalert", 4 }, /* 4.0 */
+{ "shootbul", 3 }, /* 4.0 */
+{ "mp_shnb3", 6 }, /* 4.0 */
+{ "shadoww", 29 }, /* 4.0 */
+{ "schmeisr", 11 }, /* 4.0 */
+{ "sandor", 24 }, /* 4.0 */
+{ "roughrac", 18 }, /* 4.0 */
+{ "robotron", 11 }, /* 4.0 */
+{ "revx", 14 }, /* 4.0 */
+{ "rampart", 6 }, /* 4.0 */
+{ "raiders5", 3 }, /* 4.0 */
+{ "4in1boot", 9 }, /* 4.0 */
+{ "tantr", 12 }, /* 4.0 */
+{ "pushman", 3 }, /* 4.0 */
+{ "pururun", 3 }, /* 4.0 */
+{ "puchicar", 11 }, /* 4.0 */
+{ "prikura", 19 }, /* 4.0 */
+{ "prmrsocj", 10 }, /* 4.0 */
+{ "pbillian", 14 }, /* 4.0 */
+{ "plegends", 9 }, /* 4.0 */
+{ "groovef", 23 }, /* 4.0 */
+{ "polepos2", 6 }, /* 4.0 */
+{ "polepos", 5 }, /* 4.0 */
+{ "playball", 11 }, /* 4.0 */
+{ "peterpak", 3 }, /* 4.0 */
+{ "pblbeach", 19 }, /* 4.0 */
+{ "pangpoms", 4 }, /* 4.0 */
+{ "pow", 16 }, /* 4.0 */
+{ "othellos", 20 }, /* 4.0 */
+{ "orlegend", 4 }, /* 4.0 */
+{ "olds103t", 5 }, /* 4.0 */
+{ "opwolf", 3 }, /* 4.0 */
+{ "othunder", 2 }, /* 4.0 */
+{ "opaopan", 2 }, /* 4.0 */
+{ "numanath", 7 }, /* 4.0 */
+{ "nova2001", 10 }, /* 4.0 */
+{ "nitrobal", 4 }, /* 4.0 */
+{ "ninjakd2", 10 }, /* 4.0 */
+{ "nbbatman", 15 }, /* 4.0 */
+{ "nslasher", 5 }, /* 4.0 */
+{ "mvp", 5 }, /* 4.0 */
+{ "docastle", 2 }, /* 4.0 */
+{ "mtrap", 35 }, /* 4.0 */
+{ "mmaulers", 22 }, /* 4.0 */
+{ "gdfs", 9 }, /* 4.0 */
+{ "missile", 9 }, /* 4.0 */
+{ "mpangj", 9 }, /* 4.0 */
+{ "mwalk", 11 }, /* 4.0 */
+{ "kamenrid", 4 }, /* 4.0 */
+{ "martmast", 20 }, /* 4.0 */
+{ "mtlchamp", 24 }, /* 4.0 */
+{ "mgcrystl", 2 }, /* 4.0 */
+{ "magicbub", 6 }, /* 4.0 */
+{ "mplanets", 15 }, /* 4.0 */
+{ "locomotn", 2 }, /* 4.0 */
+{ "crshrace", 8 }, /* 4.0 */
+{ "lastmisn", 10 }, /* 4.0 */
+{ "kram", 6 }, /* 4.0 */
+{ "kov2", 8 }, /* 4.0 */
+{ "kov", 19 }, /* 4.0 */
+{ "horekid", 3 }, /* 4.0 */
+{ "jungler", 6 }, /* 4.0 */
+{ "vshoot", 5 }, /* 4.0 */
+{ "intcup94", 9 }, /* 4.0 */
+{ "hotrod", 18 }, /* 4.0 */
+{ "hook", 10 }, /* 4.0 */
+{ "hexion", 7 }, /* 4.0 */
+{ "hedpanic", 10 }, /* 4.0 */
+{ "harddriv", 13 }, /* 4.0 */
+{ "guwange", 15 }, /* 4.0 */
+{ "gunnail", 3 }, /* 4.0 */
+{ "gunforc2", 11 }, /* 4.0 */
+{ "gunforce", 10 }, /* 4.0 */
+{ "gunbird", 3 }, /* 4.0 */
+{ "gunmast", 4 }, /* 4.0 */
+{ "gundealr", 3 }, /* 4.0 */
+{ "grudge", 11 }, /* 4.0 */
+{ "groundfx", 13 }, /* 4.0 */
+{ "gsword", 6 }, /* 4.0 */
+{ "gtclassc", 4 }, /* 4.0 */
+{ "gt3d", 2 }, /* 4.0 */
+{ "gt2k", 2 }, /* 4.0 */
+{ "gt99", 2 }, /* 4.0 */
+{ "gt98", 2 }, /* 4.0 */
+{ "gt97", 2 }, /* 4.0 */
+{ "gaxeduel", 20 }, /* 4.0 */
+{ "ghouls", 25 }, /* 4.0 */
+{ "ghostlop", 5 }, /* 4.0 */
+{ "gangwars", 5 }, /* 4.0 */
+{ "galspnbl", 2 }, /* 4.0 */
+{ "gground", 20 }, /* 4.0 */
+{ "gaia", 8 }, /* 4.0 */
+{ "fpoint", 5 }, /* 4.0 */
+{ "f1gp2", 6 }, /* 4.0 */
+{ "f1gp", 9 }, /* 4.0 */
+{ "excelsr", 10 }, /* 4.0 */
+{ "espgal", 6 }, /* 4.0 */
+{ "emeralda", 10 }, /* 4.0 */
+{ "ejihon", 22 }, /* 4.0 */
+{ "eaglshot", 4 }, /* 4.0 */
+{ "edf", 2 }, /* 4.0 */
+{ "dynwar", 3 }, /* 4.0 */
+{ "dragoona", 21 }, /* 4.0 */
+{ "dbz2", 2 }, /* 4.0 */
+{ "dbz", 20 }, /* 4.0 */
+{ "dsaber", 3 }, /* 4.0 */
+{ "dbreed", 10 }, /* 4.0 */
+{ "dbzvrvs", 9 }, /* 4.0 */
+{ "ddragon", 13 }, /* 4.0 */
+{ "djboy", 5 }, /* 4.0 */
+{ "dietgo", 3 }, /* 4.0 */
+{ "dharma", 3 }, /* 4.0 */
+{ "desertbr", 3 }, /* 4.0 */
+{ "deroon", 11 }, /* 4.0 */
+{ "denjinmk", 3 }, /* 4.0 */
+{ "dstlk", 8 }, /* 4.0 */
+{ "dangar", 2 }, /* 4.0 */
+{ "danceyes", 11 }, /* 4.0 */
+{ "bronx", 3 }, /* 4.0 */
+{ "cuebrick", 13 }, /* 4.0 */
+{ "cryptklr", 59 }, /* 4.0 */
+{ "crzrally", 6 }, /* 4.0 */
+{ "cottonbm", 20 }, /* 4.0 */
+{ "coolmini", 4 }, /* 4.0 */
+{ "cltchitr", 2 }, /* 4.0 */
+{ "chplftb", 43 }, /* 4.0 */
+{ "csprint", 2 }, /* 4.0 */
+{ "captaven", 3 }, /* 4.0 */
+{ "cbasebal", 6 }, /* 4.0 */
+{ "cameltry", 13 }, /* 4.0 */
+{ "calibr50", 2 }, /* 4.0 */
+{ "cabal", 6 }, /* 4.0 */
+{ "bnzabros", 12 }, /* 4.0 */
+{ "bbmanwj", 11 }, /* 4.0 */
+{ "blazer", 13 }, /* 4.0 */
+{ "blaster", 15 }, /* 4.0 */
+{ "biomtoy", 18 }, /* 4.0 */
+{ "realbrk", 6 }, /* 4.0 */
+{ "beastrzr", 12 }, /* 4.0 */
+{ "btoads", 12 }, /* 4.0 */
+{ "batcir", 8 }, /* 4.0 */
+{ "bang", 15 }, /* 4.0 */
+{ "bangball", 4 }, /* 4.0 */
+{ "balcube", 13 }, /* 4.0 */
+{ "backfire", 14 }, /* 4.0 */
+{ "aurail", 3 }, /* 4.0 */
+{ "asurabld", 3 }, /* 4.0 */
+{ "assault", 4 }, /* 4.0 */
+{ "arkarea", 4 }, /* 4.0 */
+{ "ajax", 6 }, /* 4.0 */
+{ "9ballsht", 43 }, /* 4.0 */
+{ "astrass", 24 }, /* 4.0 */
+{ "equites", 3 }, /* 4.0 */
+{ "glfgreat", 4 }, /* 4.0 */
+{ "hvoltage", 4 }, /* 4.0 */
+{ "splndrbt", 4 }, /* 4.0 */
+{ "killbldt", 20 }, /* 4.0 */
+{ "lordgun", 10 }, /* 4.0 */
+{ "roadriot", 10 }, /* 4.0 */
+{ "winspike", 13 }, /* 4.0 */
+{ "cbombers", 13 }, /* 4.0 */
+{ "hsf2", 15 }, /* 4.0 */
+{ "leds2011", 9 }, /* 4.0 */
+{ "mirax", 18 }, /* 4.0 */
+{ "cosmogng", 4 }, /* 3.11 */
+{ "batsugun", 11 }, /* 3.11 */
+{ "fghtatck", 9 }, /* 3.11 */
+{ "hyprduel", 13 }, /* 3.11 */
+{ "metalb", 7 }, /* 3.11 */
+{ "bjtwin", 2 }, /* 3.11 */
+{ "hyperath", 25 }, /* 3.11 */
+{ "mace", 16 }, /* 3.11 */
+{ "nagano98", 22 }, /* 3.11 */
+{ "weddingr", 20 }, /* 3.11 */
+{ "djboy", 5 }, /* 3.11 */
+{ "dcclubfd", 14 }, /* 3.11 */
+{ "headonch", 12 }, /* 3.11 */
+{ "mosaicf2", 20 }, /* 3.11 */
+{ "blitz99", 17 }, /* 3.11 */
+{ "offroadc", 20 }, /* 3.11 */
+{ "sss", 17 }, /* 3.11 */
+{ "teetert", 11 }, /* 3.11 */
+{ "tkdensho", 9 }, /* 3.11 */
+{ "firebarr", 13 }, /* 3.11 */
+{ "gprider1", 6 }, /* 3.11 */
+{ "zombraid", 5 }, /* 3.11 */
+{ "machbrkr", 3 }, /* 3.11 */
+{ "bkraidu", 22 }, /* 3.11 */
+{ "puyosun", 21 }, /* 3.11 */
+{ "maruchan", 21 }, /* 3.11 */
+{ "gametngk", 4 }, /* 3.11 */
+{ "47pie2", 6 }, /* 3.11 */
+{ "kirarast", 6 }, /* 3.11 */
+{ "cotton2", 20 }, /* 3.11 */
+{ "p47aces", 5 }, /* 3.11 */
+{ "progear", 23 }, /* 3.11 */
+{ "gratia", 5 }, /* 3.11 */
+{ "nebulray", 3 }, /* 3.11 */
+{ "twineag2", 14 }, /* 3.11 */
+{ "pzloop2j", 13 }, /* 3.11 */
+{ "grdforce", 19 }, /* 3.11 */
+{ "batrid", 20 }, /* 3.11 */
+{ "stmblade", 6 }, /* 3.11 */
+{ "skullfng", 12 }, /* 3.11 */
+{ "gekirido", 12 }, /* 3.11 */
+{ "tcobra2", 8 }, /* 3.11 */
+{ "boogwing", 7 }, /* 3.11 */
+{ "brvblade", 10 }, /* 3.11 */
+{ "bgaregga", 73 }, /* 3.11 */
+{ "shienryu", 19 }, /* 3.11 */
+{ "gseeker", 8 }, /* 3.11 */
+{ "mcatadv", 2 }, /* 3.11 */
+{ "1945kiii", 8 }, /* 3.11 */
+{ "kbash", 17 }, /* 3.11 */
+{ "bosco", 17 }, /* 3.11 */
+{ "mp_gaxe2", 7 }, /* 3.11 */
+{ "bonkadv", 16 }, /* 3.11 */
+{ "utoukond", 15 }, /* 3.11 */
+{ "acrobatm", 15 }, /* 3.11 */
+{ "g13knd", 35 }, /* 3.11 */
 { "uccops", 14 }, /* 3.6 */
 { "samsho5", 4 }, /* 3.1 */
 { "mslug5", 4 }, /* 3.1 */
@@ -261,7 +566,6 @@
 { "zedblade", 14 }, /* 0.87 */
 { "zunkyou", 12 }, /* 0.87 */
 { "zupapa", 8 }, /* 0.87 */
-
 { "1941", 15 }, /* 0.81 */
 { "1944", 13 }, /* 0.81 */
 { "19xx", 8 }, /* 0.81 */
@@ -936,4 +1240,3 @@
 { "zingzip", 3 }, /* 0.81 */
 { "zodiack", 3 }, /* 0.81 */
 { "zwackery", 4 }, /* 0.81 */
-
