@@ -10,26 +10,12 @@ Notes:
   There is additional code for a third Z80 in the bootleg version, I don't
   know if it's related or if its just a replacement for the 68705.
 
-- kicknrun does a PS4 STOP ERROR short after boot, but works afterwards.
-  PS4 is the mcu.
-
+  
 - Kiki Kaikai suffers from random lock-up's. It happens when the sound
   CPU misses CTS from YM2203. The processor will loop infinitely and the main
   CPU will in turn wait forever. It's difficult to meet the required level
   of synchronization. THis is kludged by filtering the 2203's busy signal.
-
-- KiKi KaiKai uses a custom 68701 MCU which isn't dumped. The bootleg Knight Boy
-  replaces it with a 68705. The bootleg is NOT 100% equivalent to the original
-  (a situation similar to Bubble Bobble): collision detection is imperfect, the
-  player can't be killed by some enemies.
-  I think the bootleggers put the custom mcu in a test rig, examined its bus
-  activity and replicated the behaviour inaccurately because they coudln't
-  figure it all out. Indeed, the 68705 code reads all the memory locations
-  related to the missing collision detection, but does nothing with them.
-
-- In the KiKi KaiKai MCU simulation, I don't bother supporting the coinage dip
-  switch settings. Therefore, it's hardwired to be 1 coin / 1 credit.
-
+  
 ***************************************************************************/
 
 #include "driver.h"
@@ -38,8 +24,11 @@ Notes:
 
 /* in machine/mexico86.c */
 extern unsigned char *mexico86_protection_ram;
+extern unsigned char *kicknrun_sharedram;
 WRITE8_HANDLER( mexico86_f008_w );
-INTERRUPT_GEN( kikikai_interrupt );
+WRITE8_HANDLER( kicknrun_f008_w );
+
+INTERRUPT_GEN( kicknrun_interrupt );
 INTERRUPT_GEN( mexico86_m68705_interrupt );
 READ8_HANDLER( mexico86_68705_portA_r );
 WRITE8_HANDLER( mexico86_68705_portA_w );
@@ -55,6 +44,133 @@ WRITE8_HANDLER( mexico86_bankswitch_w );
 VIDEO_UPDATE( mexico86 );
 VIDEO_UPDATE( kikikai );
 
+/* kicknrun / Kiki Kai Kai mcu hookup similar to Bubble Bobble */
+static int ddr1, ddr2, ddr3, ddr4;
+static int port1_in, port2_in, port3_in, port4_in;
+static int port1_out, port2_out, port3_out, port4_out;
+
+extern unsigned char *kicknrun_sharedram;
+extern READ8_HANDLER( kicknrun_sharedram_r );
+extern WRITE8_HANDLER( kicknrun_sharedram_w );
+
+
+READ8_HANDLER( kicknrun_mcu_ddr1_r )
+{
+	return ddr1;
+}
+
+WRITE8_HANDLER( kicknrun_mcu_ddr1_w )
+{
+	ddr1 = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_ddr2_r )
+{
+	return ddr2;
+}
+
+WRITE8_HANDLER( kicknrun_mcu_ddr2_w )
+{
+	ddr2 = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_ddr3_r )
+{
+	return ddr3;
+}
+
+WRITE8_HANDLER( kicknrun_mcu_ddr3_w )
+{
+	ddr3 = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_ddr4_r )
+{
+	return ddr4;
+}
+
+WRITE8_HANDLER( kicknrun_mcu_ddr4_w )
+{
+	ddr4 = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_port1_r )
+{
+	port1_in = readinputport(0);
+	return (port1_out & ddr1) | (port1_in & ~ddr1);
+}
+
+WRITE8_HANDLER( kicknrun_mcu_port1_w )
+{
+	// bit 0, 1: coin counters (?)
+	if (data & 0x01 && ~port1_out & 0x01) {
+		coin_counter_w(0,data & 0x01);
+	}
+
+	if (data & 0x02 && ~port1_out & 0x02) {
+		coin_counter_w(1,data & 0x02);
+	}
+	
+	// bit 4, 5: coin lockouts
+	coin_lockout_w( 0, (~data & 0x10) );
+	coin_lockout_w( 1, (~data & 0x10) );
+
+	// bit 7: ? (set briefly while MCU boots)
+
+	port1_out = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_port2_r )
+{
+	return (port2_out & ddr2) | (port2_in & ~ddr2);
+}
+
+WRITE8_HANDLER( kicknrun_mcu_port2_w )
+{
+	// bit 2: clock
+	// latch on high->low transition
+	if ((port2_out & 0x04) && (~data & 0x04))
+	{
+		int address = port4_out;
+
+		if (data & 0x10)
+		{
+			// read
+			if (data & 0x01)
+				port3_in = kicknrun_sharedram[address];
+			else
+				port3_in = readinputport((address & 1) + 1);
+		}
+		else
+		{
+			kicknrun_sharedram[address] = port3_out;
+		}
+	}
+
+	port2_out = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_port3_r )
+{
+	return (port3_out & ddr3) | (port3_in & ~ddr3);
+}
+
+WRITE8_HANDLER( kicknrun_mcu_port3_w )
+{
+	port3_out = data;
+}
+
+READ8_HANDLER( kicknrun_mcu_port4_r )
+{
+	return (port4_out & ddr4) | (port4_in & ~ddr4);
+}
+
+WRITE8_HANDLER( kicknrun_mcu_port4_w )
+{
+	port4_out = data;
+}
+
+
 //AT
 static READ8_HANDLER( kiki_2203_r )
 {
@@ -99,6 +215,29 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)    /* communication ram */
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( kicknrun_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1)  /* banked roms */
+	AM_RANGE(0xc000, 0xe7ff) AM_READ(shared_r)   /* shared with sound cpu */
+	AM_RANGE(0xe800, 0xe8ff) AM_READ(kicknrun_sharedram_r)    /* shared with mcu */
+	AM_RANGE(0xe900, 0xefff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xf010, 0xf010) AM_READ(input_port_5_r)
+	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)    /* communication ram - to connect 4 players's subboard */
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( kicknrun_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0xc000, 0xe7ff) AM_WRITE(shared_w) AM_BASE(&shared)  /* shared with sound cpu */
+	AM_RANGE(0xc000, 0xd4ff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_videoram) //AT: corrected size
+	AM_RANGE(0xd500, 0xd7ff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_objectram) AM_SIZE(&mexico86_objectram_size)
+	AM_RANGE(0xe800, 0xe8ff) AM_WRITE(kicknrun_sharedram_w) AM_BASE(&kicknrun_sharedram)  /* shared with mcu */
+	AM_RANGE(0xe900, 0xefff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf000, 0xf000) AM_WRITE(mexico86_bankswitch_w)  /* program and gfx ROM banks */
+	AM_RANGE(0xf008, 0xf008) AM_WRITE(kicknrun_f008_w)    /* cpu reset lines + other unknown stuff */
+	AM_RANGE(0xf018, 0xf018) AM_WRITE(MWA8_NOP)    // watchdog_reset_w },
+	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)    /* communication ram */
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0x8000, 0xa7ff) AM_READ(shared_r)
@@ -136,10 +275,37 @@ static ADDRESS_MAP_START( m68705_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0080, 0x07ff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( m6801_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0000) AM_READ(kicknrun_mcu_ddr1_r)
+	AM_RANGE(0x0001, 0x0001) AM_READ(kicknrun_mcu_ddr2_r)
+	AM_RANGE(0x0002, 0x0002) AM_READ(kicknrun_mcu_port1_r)
+	AM_RANGE(0x0003, 0x0003) AM_READ(kicknrun_mcu_port2_r)
+	AM_RANGE(0x0004, 0x0004) AM_READ(kicknrun_mcu_ddr3_r)
+	AM_RANGE(0x0005, 0x0005) AM_READ(kicknrun_mcu_ddr4_r)
+	AM_RANGE(0x0006, 0x0006) AM_READ(kicknrun_mcu_port3_r)
+	AM_RANGE(0x0007, 0x0007) AM_READ(kicknrun_mcu_port4_r)
+	AM_RANGE(0x0040, 0x00ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xf000, 0xffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( m6801_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0000) AM_WRITE(kicknrun_mcu_ddr1_w)
+	AM_RANGE(0x0001, 0x0001) AM_WRITE(kicknrun_mcu_ddr2_w)
+	AM_RANGE(0x0002, 0x0002) AM_WRITE(kicknrun_mcu_port1_w)
+	AM_RANGE(0x0003, 0x0003) AM_WRITE(kicknrun_mcu_port2_w)
+	AM_RANGE(0x0004, 0x0004) AM_WRITE(kicknrun_mcu_ddr3_w)
+	AM_RANGE(0x0005, 0x0005) AM_WRITE(kicknrun_mcu_ddr4_w)
+	AM_RANGE(0x0006, 0x0006) AM_WRITE(kicknrun_mcu_port3_w)
+	AM_RANGE(0x0007, 0x0007) AM_WRITE(kicknrun_mcu_port4_w)
+	AM_RANGE(0x0040, 0x00ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf000, 0xffff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( sub_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 ADDRESS_MAP_END
 
+
 INPUT_PORTS_START( mexico86 )
 	PORT_START      /* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -233,7 +399,213 @@ INPUT_PORTS_START( mexico86 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+/*
+ same as mexico86 except IN0 has to be set HIGH for the mcu
+ and the demo sounds switch actually works
+*/
+INPUT_PORTS_START( kicknrun )
+	PORT_START      /* IN0 */
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START      /* IN1 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE )    /* service 2 */
+
+	PORT_START      /* IN2 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START
+	/* When Bit 1 is On, the machine waits a signal from another one */
+	/* Seems like if you can join two cabinets, one as master */
+	/* and the other as slave, probably to play four players */
+	PORT_DIPNAME( 0x01, 0x01, "System Selection" )
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) ) // Screen ?
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) ) // Demo Sounds only play every 8th Demo
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( 1C_2C ) )
+	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
+
+	PORT_START
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Medium ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )
+	PORT_DIPNAME( 0x0c, 0x08, "Playing Time" )
+	PORT_DIPSETTING(    0x00, "40 Seconds" )
+	PORT_DIPSETTING(    0x0c, "One Minute" )
+	PORT_DIPSETTING(    0x08, "One Minute and 20 Sec." )
+	PORT_DIPSETTING(    0x04, "One Minute and 40 Sec." )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	/* The following dip seems to be related with the first one */
+	PORT_DIPNAME( 0x20, 0x20, "System Selection" )
+	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x00, "Number of Matches" )
+	PORT_DIPSETTING(    0x00, "2" )
+	PORT_DIPSETTING(    0x40, "6" )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Players ) )
+	PORT_DIPSETTING(    0x80, "2" )
+	PORT_DIPSETTING(    0x00, "4" )
+
+	PORT_START
+	/* the following is actually service coin 1 */
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Advance") PORT_CODE(KEYCODE_F1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+/*
+   IN0 needs to be set HIGH for the mcu which means
+   the Knight Boy bootleg will require new inputs
+   as the M68705 it uses wants to be set LOW
+*/
 INPUT_PORTS_START( kikikai )
+	PORT_START      /* IN0 */
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START      /* IN1 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START      /* IN2 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+//AT
+	PORT_START      /* DSW0 */
+	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+
+#if 0 // old coinage settings
+	PORT_DIPNAME( 0x30, 0x30, "Coin 1" )
+	PORT_DIPSETTING(    0x30, "A:1C/1C B:1C/1C" )
+	PORT_DIPSETTING(    0x20, "A:1C/2C B:2C/1C" )
+	PORT_DIPSETTING(    0x10, "A:2C/1C B:3C/1C" )
+	PORT_DIPSETTING(    0x00, "A:2C/3C B:4C/1C" )
+	PORT_DIPNAME( 0xc0, 0xc0, "Coin 2" )
+	PORT_DIPSETTING(    0xc0, "A:1C/1C B:1C/2C" )
+	PORT_DIPSETTING(    0x80, "A:1C/2C B:1C/3C" )
+	PORT_DIPSETTING(    0x40, "A:2C/1C B:1C/4C" )
+	PORT_DIPSETTING(    0x00, "A:2C/3C B:1C/6C" )
+#endif
+
+	// coinage copied from Japanese manual but type B doesn't work
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( 1C_2C ) )
+	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
+
+	PORT_START      /* DSW1 */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
+	PORT_DIPSETTING(    0x00, "50000 100000" )
+	PORT_DIPSETTING(    0x0c, "70000 150000" )
+	PORT_DIPSETTING(    0x08, "70000 200000" )
+	PORT_DIPSETTING(    0x04, "100000 300000" )
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x00, "2" )
+	PORT_DIPSETTING(    0x30, "3" )
+	PORT_DIPSETTING(    0x20, "4" )
+	PORT_DIPSETTING(    0x10, "5" )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x40, "A" )
+	PORT_DIPSETTING(    0x00, "B" )
+	PORT_DIPNAME( 0x80, 0x00, "Number Match" )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+//ZT
+
+	PORT_START
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+INPUT_PORTS_START( knightb )
 	PORT_START      /* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -337,8 +709,6 @@ INPUT_PORTS_START( kikikai )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
-
-
 static const gfx_layout charlayout =
 {
 	8,8,
@@ -365,7 +735,6 @@ static struct YM2203interface ym2203_interface =
 };
 
 
-
 static MACHINE_DRIVER_START( mexico86 )
 
 	/* basic machine hardware */
@@ -410,6 +779,60 @@ static MACHINE_DRIVER_START( mexico86 )
 	MDRV_SOUND_ROUTE(3, "mono", 1.00)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( kicknrun )
+
+	/* basic machine hardware */
+	MDRV_CPU_ADD(Z80, 6000000)      /* 6 MHz??? */
+	MDRV_CPU_PROGRAM_MAP(kicknrun_readmem,kicknrun_writemem)
+	MDRV_CPU_VBLANK_INT(kicknrun_interrupt, 1) // IRQs triggered by the MCU
+
+	MDRV_CPU_ADD(Z80, 6000000)      /* 6 MHz??? */
+	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+
+	MDRV_CPU_ADD(M6801,4000000/2)	/* xtal is 4MHz, I think it's divided by 2 internally */
+	MDRV_CPU_PROGRAM_MAP(m6801_readmem,m6801_writemem)
+	MDRV_CPU_VBLANK_INT(irq0_line_pulse,1)
+	
+	MDRV_CPU_ADD_TAG("sub", Z80, 6000000)      /* 6 MHz??? */
+	MDRV_CPU_PROGRAM_MAP(sub_cpu_map,0)
+	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)  /* frames per second, vblank duration */
+	MDRV_INTERLEAVE(100)    /* 100 CPU slices per frame - an high value to ensure proper */
+							/* synchronization of the CPUs */
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(32*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(256)
+
+	MDRV_PALETTE_INIT(RRRR_GGGG_BBBB)
+	MDRV_VIDEO_UPDATE(mexico86)
+
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
+	MDRV_SOUND_ROUTE(2, "mono", 0.30)
+	MDRV_SOUND_ROUTE(3, "mono", 1.00)
+MACHINE_DRIVER_END
+
+static MACHINE_DRIVER_START( kikikai )
+
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(kicknrun)
+	MDRV_CPU_REMOVE("sub")
+
+	/* video hardware */
+	MDRV_VIDEO_UPDATE(kikikai)
+MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( knightb )
 
@@ -422,20 +845,6 @@ static MACHINE_DRIVER_START( knightb )
 MACHINE_DRIVER_END
 
 
-static MACHINE_DRIVER_START( kikikai )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(knightb)
-
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_VBLANK_INT(kikikai_interrupt, 1) // IRQs should be triggered by the MCU, but we don't have it
-
-	MDRV_CPU_REMOVE("mcu")	// we don't have code for the 68701
-
-	/* video hardware */
-	MDRV_VIDEO_UPDATE(kikikai)
-MACHINE_DRIVER_END
-
 
 /***************************************************************************
 
@@ -453,8 +862,8 @@ ROM_START( kikikai )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )    /* 64k for the audio cpu */
 	ROM_LOAD( "a85-11.rom", 0x0000, 0x8000, CRC(cc3539db) SHA1(4239a40fdee65cba613e4b4ec54cf7899480e366) )
 
-	ROM_REGION( 0x0800, REGION_CPU3, 0 )    /* 2k for the microcontroller */
-	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x10000, REGION_CPU3, 0 )    /* 2k for the microcontroller */
+    ROM_LOAD( "a85-01_jph1020p.h8", 0xf000, 0x1000, CRC(01771197) SHA1(84430a56c66ff2781fe1ff35d4f15b332cd0af37) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a85-15.rom", 0x00000, 0x10000, CRC(aebc8c32) SHA1(77347cf5780f084a77123eb636cd0bad672a39e8) )
@@ -503,11 +912,11 @@ ROM_START( kicknrun )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )    /* 64k for the audio cpu */
 	ROM_LOAD( "a87-06.bin", 0x0000, 0x8000, CRC(1625b587) SHA1(7336384e13c114915de5e439df5731ce3fc2054a) )
 
-	ROM_REGION( 0x0800, REGION_CPU3, 0 )    /* 2k for the microcontroller */
-	ROM_LOAD( "knrmcu.bin",   0x0000, 0x0800, BAD_DUMP CRC(8e821fa0) SHA1(331f5da31d8767674e2b5bf0e7f5b5ad2535e044)  )  /* manually crafted from the Mexico '86 one */
+	ROM_REGION( 0x10000, REGION_CPU3, 0 )    /* 2k for the microcontroller */
+	ROM_LOAD( "a87-01_jph1021p.h8", 0xf000, 0x1000, CRC(9451e880) SHA1(e9a505296108645f99449d391d0ebe9ac1b9984e) ) /* MCU labeled TAITO A78 01,  JPH1021P, 185, PS4 */	
 
 	ROM_REGION( 0x10000, REGION_CPU4, 0 )    /* 64k for the cpu on the sub board */
-	ROM_LOAD( "9.bin",        0x0000, 0x4000, CRC(6a2ad32f) SHA1(42d4b97b25d219902ad215793f1d2c006ffe94dc) )
+	ROM_LOAD( "9.bin",      0x0000, 0x4000, CRC(6a2ad32f) SHA1(42d4b97b25d219902ad215793f1d2c006ffe94dc) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a87-05.bin", 0x08000, 0x08000, CRC(4eee3a8a) SHA1(2f0e4c2fb6cba48d0e2b95927fc14f0038557371) )
@@ -559,6 +968,6 @@ ROM_END
 
 
 GAME( 1986, kikikai,  0,        kikikai,  kikikai,  0, ROT90, "Taito Corporation", "KiKi KaiKai", 0 )
-GAME( 1986, knightb,  kikikai,  knightb,  kikikai,  0, ROT90, "bootleg", "Knight Boy", 0 )
-GAME( 1986, kicknrun, 0,        mexico86, mexico86, 0, ROT0,  "Taito Corporation", "Kick and Run", 0 )
+GAME( 1986, knightb,  kikikai,  knightb,  knightb,  0, ROT90, "bootleg", "Knight Boy", 0 )
+GAME( 1986, kicknrun, 0,        kicknrun, kicknrun, 0, ROT0,  "Taito Corporation", "Kick and Run", 0 )
 GAME( 1986, mexico86, kicknrun, mexico86, mexico86, 0, ROT0,  "bootleg", "Mexico 86", 0 )
